@@ -1,32 +1,40 @@
 #' Get citations in various formats from CrossRef.
-#'
+#' 
 #' @export
-#'
+#' 
 #' @param dois Search by a single DOI or many DOIs.
-#' @param format Name of the format. One of "rdf-xml", "turtle", "citeproc-json", 
-#' "citeproc-json-ish", "text", "ris", "bibtex" (default), "crossref-xml", 
-#' "datacite-xml","bibentry", or "crossref-tdm". The format "citeproc-json-ish"
-#' is a format that is not quite proper citeproc-json
-#' @param style a CSL style (for text format only). See \code{\link{get_styles}} 
-#' for options. Default: apa. If there's a style that CrossRef doesn't support 
-#' you'll get a  \code{(500) Internal Server Error}
+#' @param format Name of the format. One of "rdf-xml", "turtle", 
+#'   "citeproc-json", "citeproc-json-ish", "text", "ris", "bibtex" (default), 
+#'   "crossref-xml", "datacite-xml","bibentry", or "crossref-tdm". The format 
+#'   "citeproc-json-ish" is a format that is not quite proper citeproc-json
+#' @param style a CSL style (for text format only). See \code{\link{get_styles}}
+#'   for options. Default: apa. If there's a style that CrossRef doesn't support
+#'   you'll get a  \code{(500) Internal Server Error}
 #' @param locale Language locale. See \code{?Sys.getlocale}
 #' @param raw (logical) Return raw text in the format given by \code{format} 
-#' parameter. Default: FALSE
+#'   parameter. Default: FALSE
 #' @template moreargs
-#' @details See \url{http://www.crosscite.org/cn/} for more info on the
-#' Crossref Content Negotiation API service.
-#'
-#' DataCite DOIs: Some values of the \code{format} parameter won't work with 
-#' DataCite DOIs, but most do. See examples below.
-#' 
-#' See \code{\link{cr_agency}}
-#' 
-#' Note that the format type \code{citeproc-json} uses the CrossRef API at 
-#' \code{api.crossref.org}, while all others use \code{http://dx.doi.org}.
-#'
+#' @details See \url{http://www.crosscite.org/cn/} for more info on the Crossref
+#'   Content Negotiation API service.
+#'   
+#'   DataCite DOIs: Some values of the \code{format} parameter won't work with 
+#'   DataCite DOIs, i.e. "citeproc-json", "crossref-xml", "crossref-tdm", "onix-xml". 
+#'   
+#'   MEDRA DOIs only work with "rdf-xml", "turtle", "citeproc-json-ish", "ris", 
+#'   "bibtex", "bibentry", "onix-xml".
+#'   
+#'   See examples below.
+#'   
+#'   See \code{\link{cr_agency}}
+#'   
+#'   Note that the format type \code{citeproc-json} uses the CrossRef API at 
+#'   \code{api.crossref.org}, while all others are content negotiated via
+#'   \code{http://data.crossref.org}, \code{http://data.datacite.org} or 
+#'   \code{http://data.medra.org}. DOI agency is checked first (see 
+#'   \code{\link{cr_agency}}). 
+#'   
 #' @examples \dontrun{
-#' cr_cn(dois="10.16126/science.169.3946.635")
+#' cr_cn(dois="10.1126/science.169.3946.635")
 #' cr_cn(dois="10.1126/science.169.3946.635", "citeproc-json")
 #' cr_cn(dois="10.1126/science.169.3946.635", "citeproc-json-ish")
 #' cr_cn("10.1126/science.169.3946.635", "rdf-xml")
@@ -44,7 +52,7 @@
 #' cr_cn("10.1126/science.169.3946.635", "text", "ecoscience")
 #' cr_cn("10.1126/science.169.3946.635", "text", "heredity")
 #' cr_cn("10.1126/science.169.3946.635", "text", "oikos")
-#'
+#' 
 #' # example with many DOIs
 #' dois <- cr_r(2)
 #' cr_cn(dois, "text", "apa")
@@ -53,7 +61,7 @@
 #' stys <- get_styles()
 #' foo <- function(x){
 #'  cat(sprintf("<Style>:%s\n", x), sep = "\n\n")
-#'  cr_cn("10.1126/science.169.3946.635", "text", style=x)
+#'  cat(cr_cn("10.1126/science.169.3946.635", "text", style=x))
 #' }
 #' foo(sample(stys, 1))
 #' 
@@ -65,12 +73,11 @@
 #' ## But most do work
 #' cr_cn("10.5284/1011335", "datacite-xml")
 #' cr_cn("10.5284/1011335", "rdf-xml")
-#' cr_cn("10.5284/1011335", "turtle")
-#' cr_cn("10.5284/1011335", "citeproc-json")
+#' # cr_cn("10.5284/1011335", "turtle")
+#' cr_cn("10.5284/1011335", "citeproc-json-ish")
 #' cr_cn("10.5284/1011335", "ris")
 #' cr_cn("10.5284/1011335", "bibtex")
 #' cr_cn("10.5284/1011335", "bibentry")
-#' cr_cn("10.5284/1011335", "bibtex")
 #' 
 #' dois <- c('10.5167/UZH-30455','10.5167/UZH-49216','10.5167/UZH-503',
 #'           '10.5167/UZH-38402','10.5167/UZH-41217')
@@ -79,6 +86,9 @@
 #' cat(cr_cn(dois[3]))
 #' cat(cr_cn(dois[4]))
 #' 
+#' # Using Medra DOIs
+#' cr_cn("10.3233/ISU-150780", "onix-xml")
+#' 
 #' # Get raw output
 #' cr_cn(dois = "10.1002/app.27716", format = "citeproc-json", raw = TRUE)
 #' }
@@ -89,9 +99,21 @@
   format <- match.arg(format, c("rdf-xml", "turtle", "citeproc-json",
                                 "citeproc-json-ish", "text", "ris", "bibtex", 
                                 "crossref-xml", "datacite-xml", "bibentry", 
-                                "crossref-tdm"))
+                                "crossref-tdm", "onix-xml"))
+
   cn <- function(doi, ...){
-    url <- paste("http://dx.doi.org", doi, sep = "/")
+    agency_id <- GET_agency_id(doi)
+    if (is.na(agency_id)) {
+      stop("no resource location found", doi, message, call. = FALSE)
+    }
+    url <- paste0("http://data.", agency_id, ".org/", doi)
+    # check cn data provider
+    if (!format %in% supported_cn_types[[agency_id]]) {
+      stop(paste0("Format '", format, "' for '", doi, 
+                  "' is not supported by the DOI registration agency: '",
+                  agency_id, "'.\nTry one of the following formats: ", 
+                  paste0(supported_cn_types[[agency_id]], collapse = ", ")))
+    }
     pick <- c(
            "rdf-xml" = "application/rdf+xml",
            "turtle" = "text/turtle",
@@ -103,7 +125,8 @@
            "crossref-xml" = "application/vnd.crossref.unixref+xml",
            "datacite-xml" = "application/vnd.datacite.datacite+xml",
            "bibentry" = "application/x-bibtex",
-           "crossref-tdm" = "application/vnd.crossref.unixsd+xml")
+           "crossref-tdm" = "application/vnd.crossref.unixsd+xml",
+           "onix-xml" = "application/vnd.medra.onixdoi+xml")
     type <- pick[[format]]
     if (format == "citeproc-json") {
       response <- GET(file.path("http://api.crossref.org/works", doi, type), ...)
@@ -126,7 +149,8 @@
         "crossref-xml" = "text/xml",
         "datacite-xml" = "text/xml",
         "bibentry" = "text/plain",
-        "crossref-tdm" = "text/xml")
+        "crossref-tdm" = "text/xml",
+        "onix-xml" = "text/xml")
       parser <- select[[format]]
       if (raw) {
         content(response, "text")
@@ -157,7 +181,6 @@
   }
 }
 
-#' @importFrom bibtex read.bib
 parse_bibtex <- function(x){
   x <- gsub("@[Dd]ata", "@Misc", x)
   writeLines(x, "tmpscratch.bib")
@@ -167,10 +190,10 @@ parse_bibtex <- function(x){
 }
 
 warn_status <- function(x) {
-  if(x$status_code > 202) {
+  if (x$status_code > 202) {
     mssg <- content(x)
-    if(!is.character(mssg)) {
-      mssg <- if(x$status_code == 406) {
+    if (!is.character(mssg)) {
+      mssg <- if (x$status_code == 406) {
         "(406) - probably bad format type"
       } else {
         http_status(x)$message
@@ -181,3 +204,24 @@ warn_status <- function(x) {
     warning(sprintf("%s w/ %s", gsub("%2F", "/", httr::parse_url(x$url)$path), mssg))
   }
 }
+
+#' Get doi agency id to identify resource location
+#' 
+#' @param x doi
+#' @keywords internal
+GET_agency_id <- function(x, ...) {
+  if (is.null(x)) {
+    stop("no doi for doi agency check provided", call. = FALSE)
+  }
+  cr_agency(x)$agency$id
+}
+
+# Supported content types
+# See http://www.crosscite.org/cn/
+supported_cn_types <- list(
+  crossref = c("rdf-xml", "turtle", "citeproc-json", "citeproc-json-ish", "text", "ris", "bibtex", 
+               "crossref-xml", "bibentry", "crossref-tdm"),
+  datacite = c("rdf-xml", "turtle", "datacite-xml", "citeproc-json-ish", "text", "ris", "bibtex", 
+               "bibentry"),
+  medra = c("rdf-xml", "turtle", "citeproc-json-ish", "ris", "bibtex", "bibentry", "onix-xml")
+)
