@@ -50,7 +50,7 @@
 #' ### pdf
 #' cr_ft_text(links, "pdf", read=FALSE)
 #' cr_ft_text(links, "pdf")
-#'
+#' 
 #' ### another pensoft e.g.
 #' links <- cr_ft_links("10.3897/phytokeys.42.7604", "all")
 #' pdf_read <- cr_ft_text(url = links, type = "pdf", read=FALSE, verbose = FALSE)
@@ -85,79 +85,163 @@
 #' (links <- cr_ft_links(out$data$DOI[10], "all"))
 #' cr_ft_text(links, type = "pdf", cache=FALSE)
 #' system.time( cacheyes <- cr_ft_text(links, type = "pdf", cache=TRUE) )
-#' system.time( cacheyes <- cr_ft_text(links, type = "pdf", cache=TRUE) ) # second time is faster
+#' # second time should be faster
+#' system.time( cacheyes <- cr_ft_text(links, type = "pdf", cache=TRUE) )
 #' system.time( cacheno <- cr_ft_text(links, type = "pdf", cache=FALSE) )
 #' identical(cacheyes, cacheno)
 #'
-#'
-#' ###################### Things to stay away from
-#' ## elife
-#' #### Stay away from eLife for now, they aren't setting content types right, etc.
-#'
-#' ## elsevier - they don't actually give full text, ha ha, jokes on us!
-#' ## requires extra authentication, which we may include later on
-#' # out <- cr_members(78, filter=c(has_full_text = TRUE), works = TRUE)
-#' # links <- cr_ft_links(out$data$DOI[1], "all")
-#' # cr_ft_text(links, 'xml') # notice how this is just metadata
-#' ### elsevier articles that are open access
-#' #### one license is for open access articles, but none with full text available
-#' # cr_works(filter=list(license_url="http://www.elsevier.com/open-access/userlicense/1.0/",
-#' #                      has_full_text=TRUE))
+#' ## elsevier
+#' ## requires extra authentication
+#' out <- cr_members(78, filter=c(has_full_text = TRUE), works = TRUE)
+#' ## set key first
+#' # Sys.setenv(CROSSREF_TDM_ELSEVIER = "your-key")
+#' ## XML
+#' link <- cr_ft_links(out$data$DOI[1], "xml")
+#' # res <- cr_ft_text(url = link, type = "xml")
+#' ## plain text
+#' link <- cr_ft_links(out$data$DOI[1], "plain")
+#' # res <- cr_ft_text(url = link, "plain")
+#' 
+#' ## Wiley
+#' Sys.setenv(CROSSREF_TDM = "your-key")
+#' 
+#' ### all wiley
+#' out <- cr_members(311, filter=c(has_full_text = TRUE, type = 'journal-article'), works = TRUE)
+#' dois <- out$data$DOI[1:10]
+#' # res <- list()
+#' # for (i in seq_along(dois)) {
+#' #   tmp <- cr_ft_links(dois[i], "all")
+#' #   tmp <- setNames(tmp, "pdf")
+#' #   attr(tmp[[1]], "type") <- "pdf"
+#' #   res[[i]] <- cr_ft_text(tmp, type = "pdf", cache=FALSE)
+#' # }
+#' # res
+#' 
+#' #### older dates 
+#' out <- cr_members(311, filter=c(has_full_text = TRUE, 
+#'       type = 'journal-article', until_created_date = "2013-12-31"), works = TRUE)
+#'      
+#' dois <- out$data$DOI[1:10]
+#' # res <- list()
+#' # for (i in seq_along(dois)) {
+#' #   tmp <- cr_ft_links(dois[i], "all")
+#' #   tmp <- setNames(tmp, "pdf")
+#' #   attr(tmp[[1]], "type") <- "pdf"
+#' #   res[[i]] <- cr_ft_text(tmp, type = "pdf", cache=FALSE)
+#' # }
+#' # res
+#' 
+#' ### wiley subset with CC By 4.0 license
+#' lic <- "http://creativecommons.org/licenses/by/4.0/"
+#' out <- cr_members(311, filter=c(has_full_text = TRUE, license.url = lic), works = TRUE)
+#' dois <- out$data$DOI[1:10]
+#' # res <- list()
+#' # for (i in seq_along(dois)) {
+#' #   tmp <- cr_ft_links(dois[i], "all")
+#' #   tmp <- setNames(tmp, "pdf")
+#' #   attr(tmp[[1]], "type") <- "pdf"
+#' #   res[[i]] <- cr_ft_text(tmp, type = "pdf", cache=FALSE)
+#' # }
 #' }
 
 cr_ft_text <- function(url, type='xml', path = "~/.crossref", overwrite = TRUE,
-  read=TRUE, verbose=TRUE, cache=TRUE, ...)
-{
+  read=TRUE, verbose=TRUE, cache=TRUE, ...) {
+  
+  auth <- cr_auth(url, type)
   switch( pick_type(type, url),
-          xml = getTEXT(get_url(url, 'xml'), type, ...),
-          plain = getTEXT(get_url(url, 'xml'), type, ...),
-          pdf = getPDF(get_url(url, 'pdf'), path, overwrite, type, read, verbose, cache, ...)
+          xml = getTEXT(get_url(url, 'xml'), type, auth, ...),
+          plain = getTEXT(get_url(url, 'xml'), type, auth, ...),
+          pdf = getPDF(url = get_url(url, 'pdf'), path, auth, overwrite, type, read, verbose, cache, ...)
   )
 }
 
-get_url <- function(a,b){
-  if(is(a, "tdmurl")) a[[1]] else a[[b]]
+get_url <- function(a, b){
+  url <- if (is(a, "tdmurl")) a[[1]] else a[[b]]
+  if (grepl("pensoft", url)) {
+    url
+  } else {
+    sub("\\?.+", "", url)
+  }
 }
 
 #' @export
 #' @rdname cr_ft_text
-cr_ft_plain <- function(url, path = "~/.crossref", overwrite = TRUE, read=TRUE, verbose=TRUE, ...)
-  getTEXT(url$plain[[1]], "plain", ...)
+cr_ft_plain <- function(url, path = "~/.crossref", overwrite = TRUE, read=TRUE, verbose=TRUE, ...) {
+  getTEXT(url$plain[[1]], "plain", cr_auth(url, 'plain'), ...)
+}
 
 #' @export
 #' @rdname cr_ft_text
-cr_ft_xml <- function(url, path = "~/.crossref", overwrite = TRUE, read=TRUE, verbose=TRUE, ...)
-  getTEXT(url$xml[[1]], "xml", ...)
+cr_ft_xml <- function(url, path = "~/.crossref", overwrite = TRUE, read=TRUE, verbose=TRUE, ...) {
+  getTEXT(url$xml[[1]], "xml", cr_auth(url, 'xml'), ...)
+}
 
 #' @export
 #' @rdname cr_ft_text
-cr_ft_pdf <- function(url, path = "~/.crossref", overwrite = TRUE, read=TRUE, cache=FALSE, verbose=TRUE, ...)
-  getPDF(url$pdf[[1]], path, overwrite, "pdf", read, verbose, cache, ...)
+cr_ft_pdf <- function(url, path = "~/.crossref", overwrite = TRUE, read=TRUE, cache=FALSE, verbose=TRUE, ...) {
+  getPDF(url$pdf[[1]], path, cr_auth(url, 'pdf'), overwrite, "pdf", read, verbose, cache, ...)
+}
 
 pick_type <- function(x, z){
   x <- match.arg(x, c("xml","plain","pdf"))
-  if(length(z) == 1) {
-    avail <- attr(z, which="type")
+  if (length(z) == 1) {
+    avail <- attr(z[[1]], which = "type")
   } else {
-    avail <- vapply(z, function(x) attr(x, which="type"), character(1), USE.NAMES = FALSE)
+    avail <- vapply(z, function(x) attr(x, which = "type"), character(1), USE.NAMES = FALSE)
   }
-  if(!x %in% avail) stop("Chosen type not available in links", call. = FALSE)
+  if (!x %in% avail) stop("Chosen type not available in links", call. = FALSE)
   x
 }
 
-getTEXT <- function(x, type, ...){
-  res <- GET(x, ...)
+cr_auth <- function(url, type) {
+  mem <- attr(url, "member")
+  mem_num <- basename(mem)
+  if (mem_num %in% c(78, 263, 311)) {
+    type <- switch(type,
+                   xml = "text/xml",
+                   plain = "text/plain",
+                   pdf = "application/pdf"
+    )
+    switch(mem_num,
+        `78` = {
+          key <- Sys.getenv("CROSSREF_TDM_ELSEVIER")
+          add_headers(`X-ELS-APIKey` = key, Accept = type)
+        },
+        `263` = {
+          key <- Sys.getenv("CROSSREF_TDM")
+          add_headers(`CR-TDM-Client_Token` = key, Accept = type)
+          # add_headers(`CR-Clickthrough-Client-Token` = key, Accept = type)
+        },
+        `311` = {
+          add_headers(`CR-Clickthrough-Client-Token` = Sys.getenv("CROSSREF_TDM"), 
+                      Accept = type)
+        }
+    )
+    # add_headers(`CR-TDM-Client_Token` = key, Accept = type)
+    # add_headers(`CR-Clickthrough-Client-Token` = key, Accept = type)
+  } else {
+    NULL
+  }
+}
+
+getTEXT <- function(x, type, auth, ...){
+  res <- GET(x, auth, ...)
   switch(type,
          xml = XML::xmlParse(httr::content(res, as = "text")),
          plain = httr::content(res, as = "text"))
 }
 
-getPDF <- function(url, path, overwrite, type, read, verbose, cache=FALSE, ...) {
+getPDF <- function(url, path, auth, overwrite, type, read, verbose, cache=FALSE, ...) {
   if (!file.exists(path)) dir.create(path, showWarnings = FALSE, recursive = TRUE)
 
   # pensoft special handling
   if ( grepl("pensoft", url[[1]]) ) {
-    filepath <- file.path(path, paste0(sub("/", ".", attr(url, "doi")), ".pdf"))
+    doi <- attr(url, "doi")
+    if (is.null(doi)) {
+      tmp <- strsplit(url, "=")[[1]]
+      doi <- tmp[length(tmp)]
+    }
+    filepath <- file.path(path, paste0(sub("/", ".", doi), ".pdf"))
   } else {
     ff <- if ( !grepl(type, basename(url)) ) paste0(basename(url), ".", type) else basename(url)
     filepath <- file.path(path, ff)
@@ -170,13 +254,17 @@ getPDF <- function(url, path, overwrite, type, read, verbose, cache=FALSE, ...)
     }
   } else {
     if (verbose) message("Downloading pdf...")
-    res <- GET(url, accept("application/pdf"), write_disk(path = filepath, overwrite = overwrite), ...)
+    res <- GET(url, 
+               accept("application/pdf"), 
+               write_disk(path = filepath, overwrite = overwrite), 
+               auth, 
+               config(followlocation = TRUE), ...)
     filepath <- res$request$output$path
   }
 
   if (read) {
     if (verbose) message("Exracting text from pdf...")
-    extract_xpdf(path = filepath, ...)
+    extract_xpdf(path = filepath)
   } else {
     filepath
   }
